from csle_collector.host_manager.dao.failed_login_attempt import FailedLoginAttempt
from csle_collector.host_manager.dao.host_metrics import HostMetrics
from csle_collector.host_manager.dao.successful_login import SuccessfulLogin


class TestHostManagerDaoSuite:
    """
    Test suite for datasets data access objects (DAOs) in client_manager
    """

    def test_failed_login_attempt(self, example_failed_login_attempt: FailedLoginAttempt) -> None:
        """
        Tests creation and dict conversion of the FailedLoginAttempt DAO

        :param example_failed_login_attempt: an example FailedLoginAttempt
        :return: None
        """
        assert isinstance(example_failed_login_attempt.to_dict(), dict)
        assert isinstance(FailedLoginAttempt.from_dict(example_failed_login_attempt.to_dict()),
                          FailedLoginAttempt)
        assert (FailedLoginAttempt.from_dict(example_failed_login_attempt.to_dict()).to_dict()
                == example_failed_login_attempt.to_dict())
        assert (FailedLoginAttempt.from_dict(example_failed_login_attempt.to_dict())
                == example_failed_login_attempt)

    def test_host_metrics(self, example_host_metrics: HostMetrics) -> None:
        """
        Tests creation and dict conversion of the HostMetrics DAO

        :param example_host_metrics: an example HostMetrics
        :return: None
        """
        assert isinstance(example_host_metrics.to_dict(), dict)
        assert isinstance(HostMetrics.from_dict(example_host_metrics.to_dict()),
                          HostMetrics)
        assert (HostMetrics.from_dict(example_host_metrics.to_dict()).to_dict()
                == example_host_metrics.to_dict())
        assert (HostMetrics.from_dict(example_host_metrics.to_dict())
                == example_host_metrics)

    def test_sucessful_login(self, example_successful_login: SuccessfulLogin) -> None:
        """
        Tests creation and dict conversion of the SuccessfulLogin DAO

        :param example_successful_login: an example SuccessfulLogin
        :return: None
        """
        assert isinstance(example_successful_login.to_dict(), dict)
        assert isinstance(SuccessfulLogin.from_dict(example_successful_login.to_dict()),
                          SuccessfulLogin)
        assert (SuccessfulLogin.from_dict(example_successful_login.to_dict()).to_dict()
                == example_successful_login.to_dict())
        assert (SuccessfulLogin.from_dict(example_successful_login.to_dict())
                == example_successful_login)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import csle_collector.ryu_manager.ryu_manager_pb2 as ryu__manager__pb2

class RyuManagerStub(object):
    """Interface exported by the server
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getRyuStatus = channel.unary_unary(
                '/RyuManager/getRyuStatus',
                request_serializer=ryu__manager__pb2.GetRyuStatusMsg.SerializeToString,
                response_deserializer=ryu__manager__pb2.RyuDTO.FromString,
                )
        self.stopRyu = channel.unary_unary(
                '/RyuManager/stopRyu',
                request_serializer=ryu__manager__pb2.StopRyuMsg.SerializeToString,
                response_deserializer=ryu__manager__pb2.RyuDTO.FromString,
                )
        self.startRyu = channel.unary_unary(
                '/RyuManager/startRyu',
                request_serializer=ryu__manager__pb2.StartRyuMsg.SerializeToString,
                response_deserializer=ryu__manager__pb2.RyuDTO.FromString,
                )
        self.stopRyuMonitor = channel.unary_unary(
                '/RyuManager/stopRyuMonitor',
                request_serializer=ryu__manager__pb2.StopRyuMonitorMsg.SerializeToString,
                response_deserializer=ryu__manager__pb2.RyuDTO.FromString,
                )
        self.startRyuMonitor = channel.unary_unary(
                '/RyuManager/startRyuMonitor',
                request_serializer=ryu__manager__pb2.StartRyuMonitorMsg.SerializeToString,
                response_deserializer=ryu__manager__pb2.RyuDTO.FromString,
                )


class RyuManagerServicer(object):
    """Interface exported by the server
    """

    def getRyuStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopRyu(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startRyu(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopRyuMonitor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startRyuMonitor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RyuManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getRyuStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.getRyuStatus,
                    request_deserializer=ryu__manager__pb2.GetRyuStatusMsg.FromString,
                    response_serializer=ryu__manager__pb2.RyuDTO.SerializeToString,
            ),
            'stopRyu': grpc.unary_unary_rpc_method_handler(
                    servicer.stopRyu,
                    request_deserializer=ryu__manager__pb2.StopRyuMsg.FromString,
                    response_serializer=ryu__manager__pb2.RyuDTO.SerializeToString,
            ),
            'startRyu': grpc.unary_unary_rpc_method_handler(
                    servicer.startRyu,
                    request_deserializer=ryu__manager__pb2.StartRyuMsg.FromString,
                    response_serializer=ryu__manager__pb2.RyuDTO.SerializeToString,
            ),
            'stopRyuMonitor': grpc.unary_unary_rpc_method_handler(
                    servicer.stopRyuMonitor,
                    request_deserializer=ryu__manager__pb2.StopRyuMonitorMsg.FromString,
                    response_serializer=ryu__manager__pb2.RyuDTO.SerializeToString,
            ),
            'startRyuMonitor': grpc.unary_unary_rpc_method_handler(
                    servicer.startRyuMonitor,
                    request_deserializer=ryu__manager__pb2.StartRyuMonitorMsg.FromString,
                    response_serializer=ryu__manager__pb2.RyuDTO.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'RyuManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RyuManager(object):
    """Interface exported by the server
    """

    @staticmethod
    def getRyuStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/RyuManager/getRyuStatus',
            ryu__manager__pb2.GetRyuStatusMsg.SerializeToString,
            ryu__manager__pb2.RyuDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopRyu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/RyuManager/stopRyu',
            ryu__manager__pb2.StopRyuMsg.SerializeToString,
            ryu__manager__pb2.RyuDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startRyu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/RyuManager/startRyu',
            ryu__manager__pb2.StartRyuMsg.SerializeToString,
            ryu__manager__pb2.RyuDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopRyuMonitor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/RyuManager/stopRyuMonitor',
            ryu__manager__pb2.StopRyuMonitorMsg.SerializeToString,
            ryu__manager__pb2.RyuDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startRyuMonitor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/RyuManager/startRyuMonitor',
            ryu__manager__pb2.StartRyuMonitorMsg.SerializeToString,
            ryu__manager__pb2.RyuDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import List, Dict, Any
import time
from csle_base.json_serializable import JSONSerializable
from csle_collector.snort_ids_manager.dao.snort_ids_fast_log_alert import SnortIdsFastLogAlert


class SnortIdsRuleCounters(JSONSerializable):
    """
    DTO containing rule-statistics from the Snort IDS log
    """

    def __init__(self):
        """
        Initializes the DTO
        """
        self.rule_alerts = {}
        self.ip = ""
        self.ts = 0.0

    def add(self, alert_counters: "SnortIdsRuleCounters") -> None:
        """
        Adds another alert counters object to this one

        :param alert_counters: the counters to add
        :return: None
        """
        for k, v in alert_counters.rule_alerts.items():
            if k not in self.rule_alerts:
                self.rule_alerts[k] = int(alert_counters.rule_alerts[k])
            else:
                self.rule_alerts[k] = int(self.rule_alerts[k]) + int(alert_counters.rule_alerts[k])

    def count(self, alerts: List[SnortIdsFastLogAlert]) -> None:
        """
        Counts the list of alerts

        :param alerts: list of alerts from the log
        :return: None
        """
        for a in alerts:
            if a.rule_id not in self.rule_alerts:
                self.rule_alerts[a.rule_id] = 1
            else:
                self.rule_alerts[a.rule_id] = self.rule_alerts[a.rule_id] + 1

    @staticmethod
    def from_kafka_record(record: str) -> "SnortIdsRuleCounters":
        """
        Converts a kafka record to a DTO

        :param record: the kafka record to convert
        :return: the DTO
        """
        parts = record.split(",")
        obj = SnortIdsRuleCounters()
        obj.ts = float(parts[0])
        obj.ip = parts[1]
        rule_alerts = {}
        for i in range(2, len(parts)):
            k, v = parts[i].split(":")
            if k not in rule_alerts:
                rule_alerts[k] = int(v)
            else:
                rule_alerts[k] = rule_alerts[k] + int(v)
        obj.rule_alerts = rule_alerts
        return obj

    def update_with_kafka_record(self, record: str) -> None:
        """
        Updates the DTO with a kafka record

        :param record: the kafka record to use for updating
        :return: None
        """
        parts = record.split(",")
        self.ts = float(parts[0])
        self.ip = parts[1]
        for i in range(2, len(parts)):
            k, v = parts[i].split(":")
            if k not in self.rule_alerts:
                self.rule_alerts[k] = int(v)
            else:
                self.rule_alerts[k] = self.rule_alerts[k] + int(v)

    def to_kafka_record(self, ip: str) -> str:
        """
        Converts the DTO into a kafka record

        :param ip: the ip to add to the record in addition to the IDS statistics
        :return: a comma-separated string representing the kafka record
        """
        ts = time.time()
        record_list = [ts, ip]
        for k, v in self.rule_alerts.items():
            record_list.append(f"{k}:{v}")
        record_str = ",".join(list(map(lambda x: str(x), record_list)))
        return record_str

    def __str__(self) -> str:
        """
        :return: a string representation of the object
        """
        return f"ip: {self.ip}, ts: {self.ts}, rule_alerts: {self.rule_alerts}"

    @staticmethod
    def from_dict(d: Dict[str, Any]) -> "SnortIdsRuleCounters":
        """
        Converts a dict representaion of the object into an instance

        :param d: the dict to convert
        :return: the DTO
        """
        obj = SnortIdsRuleCounters()
        obj.ip = d["ip"]
        obj.ts = d["ts"]
        obj.rule_alerts = d["rule_alerts"]
        return obj

    def to_dict(self) -> Dict[str, Any]:
        """
        Converts the object to a dict representation
        
        :return: a dict representation of the object
        """
        d: Dict[str, Any] = {}
        d["ip"] = self.ip
        d["ts"] = self.ts
        d["rule_alerts"] = self.rule_alerts
        return d

    def copy(self) -> "SnortIdsRuleCounters":
        """
        :return: a copy of the object
        """
        c = SnortIdsRuleCounters()
        c.ip = self.ip
        c.ts = self.ts
        c.rule_alerts = self.rule_alerts.copy()
        return c

    @staticmethod
    def schema() -> "SnortIdsRuleCounters":
        """
        :return: get the schema of the DTO
        """
        return SnortIdsRuleCounters()

    @staticmethod
    def from_json_file(json_file_path: str) -> "SnortIdsRuleCounters":
        """
        Reads a json file and converts it to a DTO

        :param json_file_path: the json file path
        :return: the converted DTO
        """
        import io
        import json
        with io.open(json_file_path, 'r') as f:
            json_str = f.read()
        return SnortIdsRuleCounters.from_dict(json.loads(json_str))



from typing import Any
import pytest
import pytest_mock
import csle_collector.traffic_manager.query_traffic_manager
from csle_collector.traffic_manager.traffic_manager_pb2 import TrafficDTO
from csle_collector.traffic_manager.traffic_manager import TrafficManagerServicer


class TestTrafficManagerSuite:
    """
    Test suite for the Traffic manager
    """

    @pytest.fixture(scope='module')
    def grpc_add_to_server(self) -> Any:
        """
        Necessary fixture for pytest-grpc

        :return: the add_servicer_to_server function
        """
        from csle_collector.traffic_manager.traffic_manager_pb2_grpc import add_TrafficManagerServicer_to_server
        return add_TrafficManagerServicer_to_server

    @pytest.fixture(scope='module')
    def grpc_servicer(self) -> TrafficManagerServicer:
        """
        Necessary fixture for pytest-grpc

        :return: the host manager servicer
        """
        return TrafficManagerServicer()

    @pytest.fixture(scope='module')
    def grpc_stub_cls(self, grpc_channel):
        """
        Necessary fixture for pytest-grpc

        :param grpc_channel: the grpc channel for testing
        :return: the stub to the service
        """
        from csle_collector.traffic_manager.traffic_manager_pb2_grpc import TrafficManagerStub
        return TrafficManagerStub

    def test_getTrafficStatus(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the getTrafficStatus grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        mocker.patch('csle_collector.traffic_manager.traffic_manager.'
                     'TrafficManagerServicer._read_traffic_script', return_value="script_file")
        mocker.patch('csle_collector.traffic_manager.traffic_manager.'
                     'TrafficManagerServicer._create_traffic_script', return_value=None)
        mocker.patch('csle_collector.traffic_manager.traffic_manager.TrafficManagerServicer._get_traffic_status',
                     return_value=False)
        response: TrafficDTO = csle_collector.traffic_manager.query_traffic_manager.get_traffic_status(stub=grpc_stub)
        assert response is not None
        assert not response.running
        assert response.script == "script_file"

        mocker.patch('csle_collector.traffic_manager.traffic_manager.TrafficManagerServicer._get_traffic_status',
                     return_value=True)
        response = csle_collector.traffic_manager.query_traffic_manager.get_traffic_status(stub=grpc_stub)
        assert response is not None
        assert response.running
        assert response.script == "script_file"

    def test_stopTraffic(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the stopTraffic grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        mocker.patch('csle_collector.traffic_manager.traffic_manager.'
                     'TrafficManagerServicer._read_traffic_script', return_value="script_file")
        mocker.patch('csle_collector.traffic_manager.traffic_manager.'
                     'TrafficManagerServicer._create_traffic_script', return_value=None)
        mocker.patch('os.system', return_value=True)
        mocker.patch('csle_collector.traffic_manager.traffic_manager.TrafficManagerServicer._get_traffic_status',
                     return_value=False)
        response: TrafficDTO = csle_collector.traffic_manager.query_traffic_manager.stop_traffic(stub=grpc_stub)
        assert response is not None
        assert not response.running
        assert response.script == "script_file"

    def test_startTraffic(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the startTraffic grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        mocker.patch('csle_collector.traffic_manager.traffic_manager.'
                     'TrafficManagerServicer._read_traffic_script', return_value="script_file")
        mocker.patch('csle_collector.traffic_manager.traffic_manager.'
                     'TrafficManagerServicer._create_traffic_script', return_value=None)
        mocker.patch('os.system', return_value=True)
        mocker.patch('csle_collector.traffic_manager.traffic_manager.TrafficManagerServicer._get_traffic_status',
                     return_value=False)
        commands = ["ping localhost"]
        sleep_time = 30
        response: TrafficDTO = csle_collector.traffic_manager.query_traffic_manager.start_traffic(
            stub=grpc_stub, commands=commands, sleep_time=sleep_time)
        assert response is not None
        assert response.running
        assert response.script == "script_file"



from typing import Any
import pytest
import pytest_mock
from subprocess import CompletedProcess
from csle_collector.snort_ids_manager.snort_ids_manager_pb2 import SnortIdsLogDTO, SnortIdsMonitorDTO
from csle_collector.snort_ids_manager.dao.snort_ids_alert_counters import SnortIdsAlertCounters
from csle_collector.snort_ids_manager.dao.snort_ids_rule_counters import SnortIdsRuleCounters
from csle_collector.snort_ids_manager.dao.snort_ids_ip_alert_counters import SnortIdsIPAlertCounters
from csle_collector.snort_ids_manager.snort_ids_manager import SnortIdsManagerServicer
import csle_collector.snort_ids_manager.query_snort_ids_manager
import csle_collector.constants.constants as constants


class TestSnortIDSManagerSuite:
    """
    Test suite for the Snort IDS manager
    """

    @pytest.fixture(scope='module')
    def grpc_add_to_server(self) -> Any:
        """
        Necessary fixture for pytest-grpc

        :return: the add_servicer_to_server function
        """
        from csle_collector.snort_ids_manager.snort_ids_manager_pb2_grpc import add_SnortIdsManagerServicer_to_server
        return add_SnortIdsManagerServicer_to_server

    @pytest.fixture(scope='module')
    def grpc_servicer(self) -> SnortIdsManagerServicer:
        """
        Necessary fixture for pytest-grpc

        :return: the snort manager servicer
        """
        return SnortIdsManagerServicer()

    @pytest.fixture(scope='module')
    def grpc_stub_cls(self, grpc_channel):
        """
        Necessary fixture for pytest-grpc

        :param grpc_channel: the grpc channel for testing
        :return: the stub to the service
        """
        from csle_collector.snort_ids_manager.snort_ids_manager_pb2_grpc import SnortIdsManagerStub
        return SnortIdsManagerStub

    def test_getSnortIdsAlerts(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the getSnortIdsAlerts grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """

        def read_snort_ids_data(timestamp: float):
            if timestamp == 0:
                return SnortIdsAlertCounters(), SnortIdsRuleCounters(), SnortIdsIPAlertCounters()
            else:
                alerts = SnortIdsAlertCounters()
                alerts.severe_alerts = 100
                alerts.warning_alerts = 200
                alerts.total_alerts = 300
                alerts.alerts_weighted_by_priority = 400
                alerts.ip = "test"
                alerts.ts = 0.0
                rule_alert_counters = SnortIdsRuleCounters()
                rule_alert_counters.rule_alerts["rule_1"] = 10
                ip_alert_counters = SnortIdsIPAlertCounters()
                ip_alert_counters.severe_alerts = 1000
                ip_alert_counters.warning_alerts = 2000
                ip_alert_counters.total_alerts = 3000
                ip_alert_counters.alerts_weighted_by_priority = 4000
                return alerts, rule_alert_counters, ip_alert_counters

        read_data_mock = mocker.MagicMock(side_effect=read_snort_ids_data)
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager_util.SnortIdsManagerUtil.read_snort_ids_data',
                     side_effect=read_data_mock)
        response: SnortIdsLogDTO = csle_collector.snort_ids_manager.query_snort_ids_manager.get_snort_ids_alerts(
            stub=grpc_stub, timestamp=0, log_file_path="")
        assert response.priority_1_alerts == 0
        assert response.priority_2_alerts == 0
        assert response.priority_3_alerts == 0
        assert response.priority_4_alerts == 0
        assert response.total_alerts == 0
        assert response.warning_alerts == 0
        assert response.severe_alerts == 0
        assert response.alerts_weighted_by_priority == 0
        response = csle_collector.snort_ids_manager.query_snort_ids_manager.get_snort_ids_alerts(
            stub=grpc_stub, timestamp=1, log_file_path="")
        assert response.priority_1_alerts == 0
        assert response.priority_2_alerts == 0
        assert response.priority_3_alerts == 0
        assert response.priority_4_alerts == 0
        assert response.total_alerts == 300
        assert response.warning_alerts == 200
        assert response.severe_alerts == 100
        assert response.alerts_weighted_by_priority == 400

    def test_startSnortIdsMonitor(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the startSnortIdsMonitor grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        mocker.patch('csle_collector.snort_ids_manager.threads.snort_ids_monitor_thread.SnortIDSMonitorThread.run',
                     return_value=True)
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=True)
        kafka_ip = "test_kafka_ip"
        kafka_port = 9292
        log_file_path = "test_log_file_path"
        time_step_len_seconds = 30
        response: SnortIdsMonitorDTO = csle_collector.snort_ids_manager.query_snort_ids_manager.start_snort_ids_monitor(
            stub=grpc_stub, kafka_ip=kafka_ip, kafka_port=kafka_port, log_file_path=log_file_path,
            time_step_len_seconds=time_step_len_seconds)
        assert response.monitor_running
        assert response.snort_ids_running
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=False)
        response = csle_collector.snort_ids_manager.query_snort_ids_manager.start_snort_ids_monitor(
            stub=grpc_stub, kafka_ip=kafka_ip, kafka_port=kafka_port, log_file_path=log_file_path,
            time_step_len_seconds=time_step_len_seconds)
        assert response.monitor_running
        assert not response.snort_ids_running

    def test_stopSnortIdsMonitor(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the stopSnortIdsMonitor grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=True)
        response: SnortIdsMonitorDTO = csle_collector.snort_ids_manager.query_snort_ids_manager.stop_snort_ids_monitor(
            stub=grpc_stub)
        assert not response.monitor_running
        assert response.snort_ids_running
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=False)
        response = csle_collector.snort_ids_manager.query_snort_ids_manager.stop_snort_ids_monitor(
            stub=grpc_stub)
        assert not response.monitor_running
        assert not response.snort_ids_running

    def test_stopSnortIds(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the stopSnortIdsMonitor grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        mocker.patch('subprocess.run', return_value=CompletedProcess(args="", returncode=0, stdout="testout",
                                                                     stderr="testerr"))
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=False)
        response: SnortIdsMonitorDTO = csle_collector.snort_ids_manager.query_snort_ids_manager.stop_snort_ids(
            stub=grpc_stub)
        assert not response.monitor_running
        assert not response.snort_ids_running
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=True)
        response = csle_collector.snort_ids_manager.query_snort_ids_manager.stop_snort_ids(
            stub=grpc_stub)
        assert response.monitor_running
        assert not response.snort_ids_running

    def test_startSnortIds(self, grpc_stub, mocker: pytest_mock.MockFixture) -> None:
        """
        Tests the startSnortIdsMonitor grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        popen_res = mocker.MagicMock()
        popen_res.configure_mock(**{"stdout": "", "wait.return_value": None})
        mocker.patch('subprocess.Popen', return_value=popen_res)
        mocker.patch('subprocess.run', return_value=CompletedProcess(
            args="", returncode=0, stdout=constants.SNORT_IDS_ROUTER.SEARCH_SNORT_RUNNING, stderr="testerr"))
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=False)
        response: SnortIdsMonitorDTO = csle_collector.snort_ids_manager.query_snort_ids_manager.start_snort_ids(
            stub=grpc_stub, ingress_interface="eth0", egress_interface="eth1", subnetmask="255.255.255.0")
        assert not response.monitor_running
        assert response.snort_ids_running
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=True)
        response = csle_collector.snort_ids_manager.query_snort_ids_manager.start_snort_ids(
            stub=grpc_stub, ingress_interface="eth0", egress_interface="eth1", subnetmask="255.255.255.0")
        assert response.monitor_running
        assert response.snort_ids_running

    def test_getSnortIdsMonitorStatus(self, grpc_stub, mocker) -> None:
        """
        Tests the getSnortIdsMonitorStatus grpc

        :param grpc_stub: the stub for the GRPC server to make the request to
        :param mocker: the mocker object to mock functions with external dependencies
        :return: None
        """
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=False)
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=False)
        response: SnortIdsMonitorDTO = \
            csle_collector.snort_ids_manager.query_snort_ids_manager.get_snort_ids_monitor_status(stub=grpc_stub)
        assert not response.monitor_running
        assert not response.snort_ids_running

        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=True)
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=False)
        response = \
            csle_collector.snort_ids_manager.query_snort_ids_manager.get_snort_ids_monitor_status(stub=grpc_stub)
        assert not response.monitor_running
        assert response.snort_ids_running

        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=False)
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=True)
        response = \
            csle_collector.snort_ids_manager.query_snort_ids_manager.get_snort_ids_monitor_status(stub=grpc_stub)
        assert response.monitor_running
        assert not response.snort_ids_running

        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_snort_running',
                     return_value=True)
        mocker.patch('csle_collector.snort_ids_manager.snort_ids_manager.SnortIdsManagerServicer._is_monitor_running',
                     return_value=True)
        response = \
            csle_collector.snort_ids_manager.query_snort_ids_manager.get_snort_ids_monitor_status(stub=grpc_stub)
        assert response.monitor_running
        assert response.snort_ids_running



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StopKafkaMsg(google.protobuf.message.Message):
    """Message that the client sends to stop kafka"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopKafkaMsg = StopKafkaMsg

@typing_extensions.final
class StartKafkaMsg(google.protobuf.message.Message):
    """Message that the client sends to start kafka"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartKafkaMsg = StartKafkaMsg

@typing_extensions.final
class GetKafkaStatusMsg(google.protobuf.message.Message):
    """Message that the client sends to extract the kafka status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetKafkaStatusMsg = GetKafkaStatusMsg

@typing_extensions.final
class KafkaDTO(google.protobuf.message.Message):
    """Message that the server returns when requested by the client, contains info about Kafka"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNING_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    running: builtins.bool
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        running: builtins.bool = ...,
        topics: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["running", b"running", "topics", b"topics"]) -> None: ...

global___KafkaDTO = KafkaDTO

@typing_extensions.final
class CreateTopicMsg(google.protobuf.message.Message):
    """Message that the client sends to create a new Kafka topic"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PARTITIONS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    RETENTION_TIME_HOURS_FIELD_NUMBER: builtins.int
    name: builtins.str
    partitions: builtins.int
    replicas: builtins.int
    retention_time_hours: builtins.int
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        partitions: builtins.int = ...,
        replicas: builtins.int = ...,
        retention_time_hours: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "partitions", b"partitions", "replicas", b"replicas", "retention_time_hours", b"retention_time_hours"]) -> None: ...

global___CreateTopicMsg = CreateTopicMsg

@typing_extensions.final
class DeleteTopicMsg(google.protobuf.message.Message):
    """Message that the client sends to delete a Kafka topic"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteTopicMsg = DeleteTopicMsg



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import csle_collector.kafka_manager.kafka_manager_pb2 as kafka__manager__pb2


class KafkaManagerStub(object):
    """Interface exported by the server
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getKafkaStatus = channel.unary_unary(
                '/KafkaManager/getKafkaStatus',
                request_serializer=kafka__manager__pb2.GetKafkaStatusMsg.SerializeToString,
                response_deserializer=kafka__manager__pb2.KafkaDTO.FromString,
                )
        self.stopKafka = channel.unary_unary(
                '/KafkaManager/stopKafka',
                request_serializer=kafka__manager__pb2.StopKafkaMsg.SerializeToString,
                response_deserializer=kafka__manager__pb2.KafkaDTO.FromString,
                )
        self.startKafka = channel.unary_unary(
                '/KafkaManager/startKafka',
                request_serializer=kafka__manager__pb2.StartKafkaMsg.SerializeToString,
                response_deserializer=kafka__manager__pb2.KafkaDTO.FromString,
                )
        self.createTopic = channel.unary_unary(
                '/KafkaManager/createTopic',
                request_serializer=kafka__manager__pb2.CreateTopicMsg.SerializeToString,
                response_deserializer=kafka__manager__pb2.KafkaDTO.FromString,
                )
        self.deleteTopic = channel.unary_unary(
                '/KafkaManager/deleteTopic',
                request_serializer=kafka__manager__pb2.DeleteTopicMsg.SerializeToString,
                response_deserializer=kafka__manager__pb2.KafkaDTO.FromString,
                )


class KafkaManagerServicer(object):
    """Interface exported by the server
    """

    def getKafkaStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopKafka(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startKafka(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def createTopic(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteTopic(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KafkaManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getKafkaStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.getKafkaStatus,
                    request_deserializer=kafka__manager__pb2.GetKafkaStatusMsg.FromString,
                    response_serializer=kafka__manager__pb2.KafkaDTO.SerializeToString,
            ),
            'stopKafka': grpc.unary_unary_rpc_method_handler(
                    servicer.stopKafka,
                    request_deserializer=kafka__manager__pb2.StopKafkaMsg.FromString,
                    response_serializer=kafka__manager__pb2.KafkaDTO.SerializeToString,
            ),
            'startKafka': grpc.unary_unary_rpc_method_handler(
                    servicer.startKafka,
                    request_deserializer=kafka__manager__pb2.StartKafkaMsg.FromString,
                    response_serializer=kafka__manager__pb2.KafkaDTO.SerializeToString,
            ),
            'createTopic': grpc.unary_unary_rpc_method_handler(
                    servicer.createTopic,
                    request_deserializer=kafka__manager__pb2.CreateTopicMsg.FromString,
                    response_serializer=kafka__manager__pb2.KafkaDTO.SerializeToString,
            ),
            'deleteTopic': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteTopic,
                    request_deserializer=kafka__manager__pb2.DeleteTopicMsg.FromString,
                    response_serializer=kafka__manager__pb2.KafkaDTO.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'KafkaManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class KafkaManager(object):
    """Interface exported by the server
    """

    @staticmethod
    def getKafkaStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/KafkaManager/getKafkaStatus',
            kafka__manager__pb2.GetKafkaStatusMsg.SerializeToString,
            kafka__manager__pb2.KafkaDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopKafka(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/KafkaManager/stopKafka',
            kafka__manager__pb2.StopKafkaMsg.SerializeToString,
            kafka__manager__pb2.KafkaDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startKafka(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/KafkaManager/startKafka',
            kafka__manager__pb2.StartKafkaMsg.SerializeToString,
            kafka__manager__pb2.KafkaDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def createTopic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/KafkaManager/createTopic',
            kafka__manager__pb2.CreateTopicMsg.SerializeToString,
            kafka__manager__pb2.KafkaDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteTopic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/KafkaManager/deleteTopic',
            kafka__manager__pb2.DeleteTopicMsg.SerializeToString,
            kafka__manager__pb2.KafkaDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Dict, Any
from csle_base.json_serializable import JSONSerializable


class SnortIdsFastLogAlert(JSONSerializable):
    """
    DTO representing an alert entry in the fast log of Snort
    """

    def __init__(self, timestamp: float, priority: int, class_id: int, source_ip: str, target_ip: str, rule_id: str) \
            -> None:
        """
        Initializes the DTO

        :param timestamp: the timestamp of the record
        :param priority: the priority of the record
        :param class_id: the class id of the record
        :param source_ip: the source ip of the record
        :param target_ip: the target ip of the record
        :param rule_id: the id of the Snort rule relating to the record
        """
        self.timestamp = timestamp
        self.priority = priority
        self.class_id = class_id
        self.source_ip = source_ip
        self.target_ip = target_ip
        self.rule_id = rule_id

    def to_dict(self) -> Dict[str, Any]:
        """
        Converts the object to a dict representation

        :return: a dict representation of the object
        """
        d: Dict[str, Any] = {}
        d["timestamp"] = self.timestamp
        d["priority"] = self.priority
        d["class_id"] = self.class_id
        d["source_ip"] = self.source_ip
        d["target_ip"] = self.target_ip
        d["rule_id"] = self.rule_id
        return d

    @staticmethod
    def from_dict(parsed_stats_dict: Dict[str, Any]) -> "SnortIdsFastLogAlert":
        """
        Parses a SnortIdsFastLogAlert object from a dict

        :param parsed_stats_dict: the dict to parse
        :return: the parsed SnortIdsFastLogAlert object
        """
        snort_ids_fast_log_alert = SnortIdsFastLogAlert(parsed_stats_dict["timestamp"], parsed_stats_dict["priority"],
                                                        parsed_stats_dict["class_id"], parsed_stats_dict["source_ip"],
                                                        parsed_stats_dict["target_ip"], parsed_stats_dict["rule_id"])
        return snort_ids_fast_log_alert

    @staticmethod
    def from_json_file(json_file_path: str) -> "SnortIdsFastLogAlert":
        """
        Reads a json file and converts it to a DTO

        :param json_file_path: the json file path
        :return: the converted DTO
        """
        import io
        import json
        with io.open(json_file_path, 'r') as f:
            json_str = f.read()
        return SnortIdsFastLogAlert.from_dict(json.loads(json_str))



from typing import List
import csle_collector.client_manager.client_manager_pb2_grpc
import csle_collector.client_manager.client_manager_pb2
from csle_collector.client_manager.dao.workflows_config import WorkflowsConfig
from csle_collector.client_manager.dao.client import Client
import csle_collector.constants.constants as constants


def get_clients(stub: csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub,
                timeout=constants.GRPC.TIMEOUT_SECONDS) \
        -> csle_collector.client_manager.client_manager_pb2.ClientsDTO:
    """
    Queries the server for the client state

    :param stub: the stub to send the remote gRPC to the server
    :param timeout: the GRPC timeout (seconds)
    :return: a clientsDTO describing the state of the clients
    """
    get_clients_dto_msg = csle_collector.client_manager.client_manager_pb2.GetClientsMsg()
    clients_dto: csle_collector.client_manager.client_manager_pb2.ClientsDTO = \
        stub.getClients(get_clients_dto_msg, timeout=timeout)
    return clients_dto


def stop_clients(stub: csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub,
                 timeout=constants.GRPC.TIMEOUT_SECONDS):
    """
    Stops the client arrival process

    :param stub: the stub to the gRPC server
    :param timeout: the GRPC timeout (seconds)
    :return: a clientsDTO describing the state of the clients
    """
    stop_clients_msg = csle_collector.client_manager.client_manager_pb2.StopClientsMsg()
    clients_dto: csle_collector.client_manager.client_manager_pb2.ClientsDTO = \
        stub.stopClients(stop_clients_msg, timeout=timeout)
    return clients_dto


def start_clients(stub: csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub,
                  time_step_len_seconds: int, workflows_config: WorkflowsConfig, clients: List[Client],
                  timeout=constants.GRPC.TIMEOUT_SECONDS) \
        -> csle_collector.client_manager.client_manager_pb2.ClientsDTO:
    """
    Starts the client arrival process

    :param stub: the stub to the gRPC server
    :param time_step_len_seconds: length of a time-step in the emulation
    :param workflows_config: configuration of the workflows
    :param clients: list of client profiles
    :param timeout: the timeout for sending a request to the GRPC server
    :return: a clients DTO describing the state of the clients
    """
    clients_grpcs = list(map(lambda x: x.to_grpc_object(), clients))
    workflows_config_grpc = workflows_config.to_grpc_object()
    start_clients_msg = csle_collector.client_manager.client_manager_pb2.StartClientsMsg(
        time_step_len_seconds=time_step_len_seconds, clients=clients_grpcs,
        workflows_config=workflows_config_grpc)
    clients_dto: csle_collector.client_manager.client_manager_pb2.ClientsDTO = \
        stub.startClients(start_clients_msg, timeout=timeout)
    return clients_dto


def stop_producer(stub: csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub,
                  timeout=constants.GRPC.TIMEOUT_SECONDS):
    """
    Stops the producer process

    :param stub: the stub to the gRPC server
    :param timeout: the GRPC timeout (seconds)
    :return: a clientsDTO describing the state of the clients
    """
    stop_producer_msg = csle_collector.client_manager.client_manager_pb2.StopProducerMsg()
    clients_dto = stub.stopProducer(stop_producer_msg, timeout=timeout)
    return clients_dto


def start_producer(stub: csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub, ip: str, port: int,
                   time_step_len_seconds: int, timeout=constants.GRPC.TIMEOUT_SECONDS):
    """
    Stops the producer process

    :param stub: the stub to the gRPC server
    :param ip: ip of the kafka server to produce to
    :param port: port of the kafka server to produce to
    :param timeout: the GRPC timeout (seconds)
    :return: a clientsDTO describing the state of the clients
    """
    start_producer_msg = csle_collector.client_manager.client_manager_pb2.StartProducerMsg(
        ip=ip,
        port=port,
        time_step_len_seconds=time_step_len_seconds
    )
    clients_dto = stub.startProducer(start_producer_msg, timeout=timeout)
    return clients_dto



from typing import List
import csle_collector.docker_stats_manager.docker_stats_manager_pb2_grpc
import csle_collector.docker_stats_manager.docker_stats_manager_pb2
import csle_collector.constants.constants as constants


def get_docker_stats_manager_status(
        stub: csle_collector.docker_stats_manager.docker_stats_manager_pb2_grpc.DockerStatsManagerStub,
        timeout=constants.GRPC.TIMEOUT_SECONDS) \
        -> csle_collector.docker_stats_manager.docker_stats_manager_pb2.DockerStatsMonitorDTO:
    """
    Queries the docker stats manager for the status

    :param stub: the stub to send the remote gRPC to the server
    :param timeout: the GRPC timeout (seconds)
    :return: a DockerStatsManagerDTO describing the status of the server
    """
    get_docker_stats_server_msg = \
        csle_collector.docker_stats_manager.docker_stats_manager_pb2.GetDockerStatsMonitorStatusMsg()
    docker_stats_manager_dto: csle_collector.docker_stats_manager.docker_stats_manager_pb2.DockerStatsMonitorDTO \
        = stub.getDockerStatsMonitorStatus(get_docker_stats_server_msg, timeout=timeout)
    return docker_stats_manager_dto


def start_docker_stats_monitor(
        stub: csle_collector.docker_stats_manager.docker_stats_manager_pb2_grpc.DockerStatsManagerStub,
        emulation: str, execution_first_ip_octet: int, kafka_ip: str, stats_queue_maxsize: int,
        time_step_len_seconds: int, kafka_port: int,
        containers: List[csle_collector.docker_stats_manager.docker_stats_manager_pb2.ContainerIp],
        timeout=constants.GRPC.OPERATION_TIMEOUT_SECONDS) \
        -> csle_collector.docker_stats_manager.docker_stats_manager_pb2.DockerStatsMonitorDTO:
    """
    Sends a request to the docker stats manager to start a new monitor thread

    :param stub: the stub to send the remote gRPC to the server
    :param emulation: the name of the emulation
    :param execution_first_ip_octet: the first octet of the ip of the execution
    :param kafka_ip: the ip of the Kafka server to push stats to
    :param stats_queue_maxsize: the maximum size of the queue
    :param the length of the period between pushing data to Kafka
    :param kafka_port: the port of the Kafka server
    :param containers: list of names and ips of  containers to monitor
    :param timeout: the GRPC timeout (seconds)
    :return: a DockerStatsManagerDTO describing the status of the server
    """
    start_docker_stats_monitor_msg = \
        csle_collector.docker_stats_manager.docker_stats_manager_pb2.StartDockerStatsMonitorMsg(
            emulation=emulation, execution_first_ip_octet=execution_first_ip_octet,
            kafka_ip=kafka_ip, stats_queue_maxsize=stats_queue_maxsize,
            time_step_len_seconds=time_step_len_seconds, kafka_port=kafka_port, containers=containers
        )
    docker_stats_manager_dto: csle_collector.docker_stats_manager.docker_stats_manager_pb2.DockerStatsMonitorDTO \
        = stub.startDockerStatsMonitor(start_docker_stats_monitor_msg, timeout=timeout)
    return docker_stats_manager_dto


def stop_docker_stats_monitor(
        stub: csle_collector.docker_stats_manager.docker_stats_manager_pb2_grpc.DockerStatsManagerStub,
        emulation: str, execution_first_ip_octet: int, timeout=constants.GRPC.OPERATION_TIMEOUT_SECONDS) \
        -> csle_collector.docker_stats_manager.docker_stats_manager_pb2.DockerStatsMonitorDTO:
    """
    Sends a request to the docker stats manager to start a new monitor thread

    :param stub: the stub to send the remote gRPC to the server
    :param emulation: the emulation for which the monitor should be stopped
    :param execution_first_ip_octet: the first octet of the ip of the execution
    :param timeout: the GRPC timeout (seconds)
    :return: a DockerStatsManagerDTO describing the status of the server
    """
    stop_docker_stats_monitor_msg = \
        csle_collector.docker_stats_manager.docker_stats_manager_pb2.StopDockerStatsMonitorMsg(
            emulation=emulation, execution_first_ip_octet=execution_first_ip_octet)
    docker_stats_manager_dto: csle_collector.docker_stats_manager.docker_stats_manager_pb2.DockerStatsMonitorDTO \
        = stub.stopDockerStatsMonitor(stop_docker_stats_monitor_msg, timeout=timeout)
    return docker_stats_manager_dto



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetOSSECIdsAlertsMsg(google.protobuf.message.Message):
    """Message that the client sends to extract the IDS log statistics from a given timestamp"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    LOG_FILE_PATH_FIELD_NUMBER: builtins.int
    timestamp: builtins.float
    log_file_path: builtins.str
    def __init__(
        self,
        *,
        timestamp: builtins.float = ...,
        log_file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_file_path", b"log_file_path", "timestamp", b"timestamp"]) -> None: ...

global___GetOSSECIdsAlertsMsg = GetOSSECIdsAlertsMsg

@typing_extensions.final
class StopOSSECIdsMonitorMsg(google.protobuf.message.Message):
    """Message that the client sends to stop the OSSECIdsMonitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopOSSECIdsMonitorMsg = StopOSSECIdsMonitorMsg

@typing_extensions.final
class StopOSSECIdsMsg(google.protobuf.message.Message):
    """Message that the client sends to stop the OSSECIds"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopOSSECIdsMsg = StopOSSECIdsMsg

@typing_extensions.final
class StartOSSECIdsMsg(google.protobuf.message.Message):
    """Message that the client sends to start the OSSECIds"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartOSSECIdsMsg = StartOSSECIdsMsg

@typing_extensions.final
class StartOSSECIdsMonitorMsg(google.protobuf.message.Message):
    """Message that the client sends to start the OSSECIdsMonitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KAFKA_IP_FIELD_NUMBER: builtins.int
    KAFKA_PORT_FIELD_NUMBER: builtins.int
    LOG_FILE_PATH_FIELD_NUMBER: builtins.int
    TIME_STEP_LEN_SECONDS_FIELD_NUMBER: builtins.int
    kafka_ip: builtins.str
    kafka_port: builtins.int
    log_file_path: builtins.str
    time_step_len_seconds: builtins.int
    def __init__(
        self,
        *,
        kafka_ip: builtins.str = ...,
        kafka_port: builtins.int = ...,
        log_file_path: builtins.str = ...,
        time_step_len_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kafka_ip", b"kafka_ip", "kafka_port", b"kafka_port", "log_file_path", b"log_file_path", "time_step_len_seconds", b"time_step_len_seconds"]) -> None: ...

global___StartOSSECIdsMonitorMsg = StartOSSECIdsMonitorMsg

@typing_extensions.final
class GetOSSECIdsMonitorStatusMsg(google.protobuf.message.Message):
    """Message that the client sends to get the status of the OSSECIdsMonitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetOSSECIdsMonitorStatusMsg = GetOSSECIdsMonitorStatusMsg

@typing_extensions.final
class OSSECIdsMonitorDTO(google.protobuf.message.Message):
    """Message that the server returns when asked about the status of the OSSEC IDS Monitor thread and OSSEC itself"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITOR_RUNNING_FIELD_NUMBER: builtins.int
    OSSEC_IDS_RUNNING_FIELD_NUMBER: builtins.int
    monitor_running: builtins.bool
    ossec_ids_running: builtins.bool
    def __init__(
        self,
        *,
        monitor_running: builtins.bool = ...,
        ossec_ids_running: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitor_running", b"monitor_running", "ossec_ids_running", b"ossec_ids_running"]) -> None: ...

global___OSSECIdsMonitorDTO = OSSECIdsMonitorDTO

@typing_extensions.final
class OSSECIdsLogDTO(google.protobuf.message.Message):
    """Message that the server returns when requested by the client, contains info about the OSSEC IDS log"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    ATTEMPTED_ADMIN_ALERTS_FIELD_NUMBER: builtins.int
    TOTAL_ALERTS_FIELD_NUMBER: builtins.int
    WARNING_ALERTS_FIELD_NUMBER: builtins.int
    SEVERE_ALERTS_FIELD_NUMBER: builtins.int
    ALERTS_WEIGHTED_BY_LEVEL_FIELD_NUMBER: builtins.int
    LEVEL_0_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_1_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_2_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_3_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_4_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_5_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_6_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_7_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_8_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_9_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_10_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_11_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_12_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_13_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_14_ALERTS_FIELD_NUMBER: builtins.int
    LEVEL_15_ALERTS_FIELD_NUMBER: builtins.int
    INVALID_LOGIN_ALERTS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_SUCCESS_ALERTS_FIELD_NUMBER: builtins.int
    AUTHENTICATION_FAILED_ALERTS_FIELD_NUMBER: builtins.int
    CONNECTION_ATTEMPT_ALERTS_FIELD_NUMBER: builtins.int
    ATTACKS_ALERTS_FIELD_NUMBER: builtins.int
    ADDUSER_ALERTS_FIELD_NUMBER: builtins.int
    SSHD_ALERTS_FIELD_NUMBER: builtins.int
    IDS_ALERTS_FIELD_NUMBER: builtins.int
    FIREWALL_ALERTS_FIELD_NUMBER: builtins.int
    SQUID_ALERTS_FIELD_NUMBER: builtins.int
    APACHE_ALERTS_FIELD_NUMBER: builtins.int
    SYSLOG_ALERTS_FIELD_NUMBER: builtins.int
    timestamp: builtins.float
    ip: builtins.str
    attempted_admin_alerts: builtins.int
    total_alerts: builtins.int
    warning_alerts: builtins.int
    severe_alerts: builtins.int
    alerts_weighted_by_level: builtins.int
    level_0_alerts: builtins.int
    level_1_alerts: builtins.int
    level_2_alerts: builtins.int
    level_3_alerts: builtins.int
    level_4_alerts: builtins.int
    level_5_alerts: builtins.int
    level_6_alerts: builtins.int
    level_7_alerts: builtins.int
    level_8_alerts: builtins.int
    level_9_alerts: builtins.int
    level_10_alerts: builtins.int
    level_11_alerts: builtins.int
    level_12_alerts: builtins.int
    level_13_alerts: builtins.int
    level_14_alerts: builtins.int
    level_15_alerts: builtins.int
    invalid_login_alerts: builtins.int
    authentication_success_alerts: builtins.int
    authentication_failed_alerts: builtins.int
    connection_attempt_alerts: builtins.int
    attacks_alerts: builtins.int
    adduser_alerts: builtins.int
    sshd_alerts: builtins.int
    ids_alerts: builtins.int
    firewall_alerts: builtins.int
    squid_alerts: builtins.int
    apache_alerts: builtins.int
    syslog_alerts: builtins.int
    def __init__(
        self,
        *,
        timestamp: builtins.float = ...,
        ip: builtins.str = ...,
        attempted_admin_alerts: builtins.int = ...,
        total_alerts: builtins.int = ...,
        warning_alerts: builtins.int = ...,
        severe_alerts: builtins.int = ...,
        alerts_weighted_by_level: builtins.int = ...,
        level_0_alerts: builtins.int = ...,
        level_1_alerts: builtins.int = ...,
        level_2_alerts: builtins.int = ...,
        level_3_alerts: builtins.int = ...,
        level_4_alerts: builtins.int = ...,
        level_5_alerts: builtins.int = ...,
        level_6_alerts: builtins.int = ...,
        level_7_alerts: builtins.int = ...,
        level_8_alerts: builtins.int = ...,
        level_9_alerts: builtins.int = ...,
        level_10_alerts: builtins.int = ...,
        level_11_alerts: builtins.int = ...,
        level_12_alerts: builtins.int = ...,
        level_13_alerts: builtins.int = ...,
        level_14_alerts: builtins.int = ...,
        level_15_alerts: builtins.int = ...,
        invalid_login_alerts: builtins.int = ...,
        authentication_success_alerts: builtins.int = ...,
        authentication_failed_alerts: builtins.int = ...,
        connection_attempt_alerts: builtins.int = ...,
        attacks_alerts: builtins.int = ...,
        adduser_alerts: builtins.int = ...,
        sshd_alerts: builtins.int = ...,
        ids_alerts: builtins.int = ...,
        firewall_alerts: builtins.int = ...,
        squid_alerts: builtins.int = ...,
        apache_alerts: builtins.int = ...,
        syslog_alerts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["adduser_alerts", b"adduser_alerts", "alerts_weighted_by_level", b"alerts_weighted_by_level", "apache_alerts", b"apache_alerts", "attacks_alerts", b"attacks_alerts", "attempted_admin_alerts", b"attempted_admin_alerts", "authentication_failed_alerts", b"authentication_failed_alerts", "authentication_success_alerts", b"authentication_success_alerts", "connection_attempt_alerts", b"connection_attempt_alerts", "firewall_alerts", b"firewall_alerts", "ids_alerts", b"ids_alerts", "invalid_login_alerts", b"invalid_login_alerts", "ip", b"ip", "level_0_alerts", b"level_0_alerts", "level_10_alerts", b"level_10_alerts", "level_11_alerts", b"level_11_alerts", "level_12_alerts", b"level_12_alerts", "level_13_alerts", b"level_13_alerts", "level_14_alerts", b"level_14_alerts", "level_15_alerts", b"level_15_alerts", "level_1_alerts", b"level_1_alerts", "level_2_alerts", b"level_2_alerts", "level_3_alerts", b"level_3_alerts", "level_4_alerts", b"level_4_alerts", "level_5_alerts", b"level_5_alerts", "level_6_alerts", b"level_6_alerts", "level_7_alerts", b"level_7_alerts", "level_8_alerts", b"level_8_alerts", "level_9_alerts", b"level_9_alerts", "severe_alerts", b"severe_alerts", "squid_alerts", b"squid_alerts", "sshd_alerts", b"sshd_alerts", "syslog_alerts", b"syslog_alerts", "timestamp", b"timestamp", "total_alerts", b"total_alerts", "warning_alerts", b"warning_alerts"]) -> None: ...

global___OSSECIdsLogDTO = OSSECIdsLogDTO



"""
Type of process that generates new clients for an emulation
"""

from enum import IntEnum


class ClientArrivalType(IntEnum):
    """
    Enum representing the different process types for generating client process in an emulation
    """
    CONSTANT = 0
    SINE_MODULATED = 1
    SPIKING = 2
    PIECE_WISE_CONSTANT = 3
    EPTMP = 4



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import csle_collector.client_manager.client_manager_pb2 as client__manager__pb2


class ClientManagerStub(object):
    """Interface exported by the server
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getClients = channel.unary_unary(
                '/ClientManager/getClients',
                request_serializer=client__manager__pb2.GetClientsMsg.SerializeToString,
                response_deserializer=client__manager__pb2.ClientsDTO.FromString,
                )
        self.stopClients = channel.unary_unary(
                '/ClientManager/stopClients',
                request_serializer=client__manager__pb2.StopClientsMsg.SerializeToString,
                response_deserializer=client__manager__pb2.ClientsDTO.FromString,
                )
        self.startClients = channel.unary_unary(
                '/ClientManager/startClients',
                request_serializer=client__manager__pb2.StartClientsMsg.SerializeToString,
                response_deserializer=client__manager__pb2.ClientsDTO.FromString,
                )
        self.startProducer = channel.unary_unary(
                '/ClientManager/startProducer',
                request_serializer=client__manager__pb2.StartProducerMsg.SerializeToString,
                response_deserializer=client__manager__pb2.ClientsDTO.FromString,
                )
        self.stopProducer = channel.unary_unary(
                '/ClientManager/stopProducer',
                request_serializer=client__manager__pb2.StopProducerMsg.SerializeToString,
                response_deserializer=client__manager__pb2.ClientsDTO.FromString,
                )


class ClientManagerServicer(object):
    """Interface exported by the server
    """

    def getClients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopClients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startClients(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startProducer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopProducer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClientManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getClients': grpc.unary_unary_rpc_method_handler(
                    servicer.getClients,
                    request_deserializer=client__manager__pb2.GetClientsMsg.FromString,
                    response_serializer=client__manager__pb2.ClientsDTO.SerializeToString,
            ),
            'stopClients': grpc.unary_unary_rpc_method_handler(
                    servicer.stopClients,
                    request_deserializer=client__manager__pb2.StopClientsMsg.FromString,
                    response_serializer=client__manager__pb2.ClientsDTO.SerializeToString,
            ),
            'startClients': grpc.unary_unary_rpc_method_handler(
                    servicer.startClients,
                    request_deserializer=client__manager__pb2.StartClientsMsg.FromString,
                    response_serializer=client__manager__pb2.ClientsDTO.SerializeToString,
            ),
            'startProducer': grpc.unary_unary_rpc_method_handler(
                    servicer.startProducer,
                    request_deserializer=client__manager__pb2.StartProducerMsg.FromString,
                    response_serializer=client__manager__pb2.ClientsDTO.SerializeToString,
            ),
            'stopProducer': grpc.unary_unary_rpc_method_handler(
                    servicer.stopProducer,
                    request_deserializer=client__manager__pb2.StopProducerMsg.FromString,
                    response_serializer=client__manager__pb2.ClientsDTO.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ClientManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClientManager(object):
    """Interface exported by the server
    """

    @staticmethod
    def getClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ClientManager/getClients',
            client__manager__pb2.GetClientsMsg.SerializeToString,
            client__manager__pb2.ClientsDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ClientManager/stopClients',
            client__manager__pb2.StopClientsMsg.SerializeToString,
            client__manager__pb2.ClientsDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ClientManager/startClients',
            client__manager__pb2.StartClientsMsg.SerializeToString,
            client__manager__pb2.ClientsDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startProducer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ClientManager/startProducer',
            client__manager__pb2.StartProducerMsg.SerializeToString,
            client__manager__pb2.ClientsDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopProducer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ClientManager/stopProducer',
            client__manager__pb2.StopProducerMsg.SerializeToString,
            client__manager__pb2.ClientsDTO.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StopTrafficMsg(google.protobuf.message.Message):
    """Message that the client sends to stop the traffic generator"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopTrafficMsg = StopTrafficMsg

@typing_extensions.final
class StartTrafficMsg(google.protobuf.message.Message):
    """Message that the client sends to start the traffic generator"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLEEPTIME_FIELD_NUMBER: builtins.int
    COMMANDS_FIELD_NUMBER: builtins.int
    sleepTime: builtins.int
    @property
    def commands(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        sleepTime: builtins.int = ...,
        commands: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commands", b"commands", "sleepTime", b"sleepTime"]) -> None: ...

global___StartTrafficMsg = StartTrafficMsg

@typing_extensions.final
class GetTrafficStatusMsg(google.protobuf.message.Message):
    """Message that the client sends to extract the status of the traffic generator"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetTrafficStatusMsg = GetTrafficStatusMsg

@typing_extensions.final
class TrafficDTO(google.protobuf.message.Message):
    """Message that the server returns when requested by the client, contains info about the traffic generator"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNING_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    running: builtins.bool
    script: builtins.str
    def __init__(
        self,
        *,
        running: builtins.bool = ...,
        script: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["running", b"running", "script", b"script"]) -> None: ...

global___TrafficDTO = TrafficDTO



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StopDockerStatsMonitorMsg(google.protobuf.message.Message):
    """Message that the client sends to stop the docker stats monitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    EXECUTION_FIRST_IP_OCTET_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    execution_first_ip_octet: builtins.int
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        execution_first_ip_octet: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation", b"emulation", "execution_first_ip_octet", b"execution_first_ip_octet"]) -> None: ...

global___StopDockerStatsMonitorMsg = StopDockerStatsMonitorMsg

@typing_extensions.final
class ContainerIp(google.protobuf.message.Message):
    """DTO representing a pair of ip and container name"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_FIELD_NUMBER: builtins.int
    CONTAINER_FIELD_NUMBER: builtins.int
    ip: builtins.str
    container: builtins.str
    def __init__(
        self,
        *,
        ip: builtins.str = ...,
        container: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container", b"container", "ip", b"ip"]) -> None: ...

global___ContainerIp = ContainerIp

@typing_extensions.final
class StartDockerStatsMonitorMsg(google.protobuf.message.Message):
    """Message that the client sends to start the docker stats monitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMULATION_FIELD_NUMBER: builtins.int
    EXECUTION_FIRST_IP_OCTET_FIELD_NUMBER: builtins.int
    KAFKA_IP_FIELD_NUMBER: builtins.int
    STATS_QUEUE_MAXSIZE_FIELD_NUMBER: builtins.int
    TIME_STEP_LEN_SECONDS_FIELD_NUMBER: builtins.int
    KAFKA_PORT_FIELD_NUMBER: builtins.int
    CONTAINERS_FIELD_NUMBER: builtins.int
    emulation: builtins.str
    execution_first_ip_octet: builtins.int
    kafka_ip: builtins.str
    stats_queue_maxsize: builtins.int
    time_step_len_seconds: builtins.int
    kafka_port: builtins.int
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerIp]: ...
    def __init__(
        self,
        *,
        emulation: builtins.str = ...,
        execution_first_ip_octet: builtins.int = ...,
        kafka_ip: builtins.str = ...,
        stats_queue_maxsize: builtins.int = ...,
        time_step_len_seconds: builtins.int = ...,
        kafka_port: builtins.int = ...,
        containers: collections.abc.Iterable[global___ContainerIp] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["containers", b"containers", "emulation", b"emulation", "execution_first_ip_octet", b"execution_first_ip_octet", "kafka_ip", b"kafka_ip", "kafka_port", b"kafka_port", "stats_queue_maxsize", b"stats_queue_maxsize", "time_step_len_seconds", b"time_step_len_seconds"]) -> None: ...

global___StartDockerStatsMonitorMsg = StartDockerStatsMonitorMsg

@typing_extensions.final
class GetDockerStatsMonitorStatusMsg(google.protobuf.message.Message):
    """Message that the client sends to extract the status of the docker stats monitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDockerStatsMonitorStatusMsg = GetDockerStatsMonitorStatusMsg

@typing_extensions.final
class DockerStatsMonitorDTO(google.protobuf.message.Message):
    """Message that the server returns when requested by the client, contains info about the docker stats monitor"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_MONITORS_FIELD_NUMBER: builtins.int
    EMULATIONS_FIELD_NUMBER: builtins.int
    EMULATION_EXECUTIONS_FIELD_NUMBER: builtins.int
    num_monitors: builtins.int
    @property
    def emulations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def emulation_executions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        num_monitors: builtins.int = ...,
        emulations: collections.abc.Iterable[builtins.str] | None = ...,
        emulation_executions: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emulation_executions", b"emulation_executions", "emulations", b"emulations", "num_monitors", b"num_monitors"]) -> None: ...

global___DockerStatsMonitorDTO = DockerStatsMonitorDTO
